<?php

use GuzzleHttp\Client;
use OpenStack\Common\Transport\HandlerStack;
use OpenStack\Common\Transport\Middleware;
use OpenStack\Identity\v3\Service;
use OpenStack\Common\Auth\Token;
use OpenStack\Common\Transport\Utils;

class genTokenOptions
{
	private $optionsGlobal;
	
	private $stack;
	private $backup = [];

	public function __construct($options){
		echo "test";
		
		$this->stack = HandlerStack::create();

		$httpClient = new Client([
            'base_uri' => Utils::normalizeUrl($options['authUrl']),
            'handler'  => $this->stack,
        ]);
		
        $options['identityService'] = Service::factory($httpClient);
		
		$options['authHandler'] = function () use ($options) {
			return $options['identityService']->generateToken($options);
        };
		
		$this->optionsGlobal['Common'] = $options;
	}
 
		/**
     * @codeCoverageIgnore
     */
    private function addDebugMiddleware(array $options, HandlerStack &$stack)
    {
        if (!empty($options['debugLog'])
            && !empty($options['logger'])
            && !empty($options['messageFormatter'])
        ) {
            $stack->push(GuzzleMiddleware::log($options['logger'], $options['messageFormatter']));
        }
    }
	
	public function genComputeToken(){
		$options = $this->optionsGlobal['Common'];
		$options['catalogName'] = 'nova';
		$options['catalogType'] = 'compute';
		$options['region'] = 'RegionOne';
		
		list($token, $baseUrl) = $options['identityService']->authenticate($options);
		var_dump($token);		
		//$stack = HandlerStack::create();
        $this->stack->push(Middleware::authHandler($options['authHandler'], $token));
		
		$this->addDebugMiddleware($options, $this->stack);
		
		$options['httpClient'] = new Client([
            'base_uri' => Utils::normalizeUrl($baseUrl),
            'handler'  => $this->stack,
        ]);
		$this->backup['Compute'] = array('token' => serialize($token), 'baseUrl' => $baseUrl );		
		$this->optionsGlobal['Compute'] = $options;
	}
	
	public function loadComputeBackup($opt){
		
		$options = $this->optionsGlobal['Common'];
		$options['catalogName'] = 'nova';
		$options['catalogType'] = 'compute';
		$options['region'] = 'RegionOne';
		
		//list($token, $baseUrl) = $options['identityService']->authenticate($options);
		$this->backup['Compute'] = unserialize($opt);
		$token = unserialize($this->backup['Compute']	['token']);
		$baseUrl = $this->backup['Compute']['baseUrl'];
		
		//$stack = HandlerStack::create();
    
		$this->stack->push(Middleware::authHandler($options['authHandler'], $token));
		
		$this->addDebugMiddleware($options, $this->stack);
		
		$options['httpClient'] = new Client([
            'base_uri' => Utils::normalizeUrl($baseUrl),
            'handler'  => $this->stack,
        ]);
		$this->backup['Compute'] = array('token' => serialize($token), 'baseUrl' => $baseUrl );		
		$this->optionsGlobal['Compute'] = $options;
	}

	public function getBackup($service){
		return serialize($this->backup[$service]);
	}
	
	public function getOptionsCompute(){
		return $this->optionsGlobal['Compute'];
	}
}
